documentationtools.Pipe
=======================

.. inheritance-diagram:: abjad.tools.documentationtools.Pipe.Pipe.Pipe
   :private-bases:

.. autoclass:: abjad.tools.documentationtools.Pipe.Pipe.Pipe

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.documentationtools.Pipe.Pipe.Pipe.arguments

.. autoattribute:: abjad.tools.documentationtools.Pipe.Pipe.Pipe.executable

.. autoattribute:: abjad.tools.documentationtools.Pipe.Pipe.Pipe.timeout

Methods
-------

.. automethod:: abjad.tools.documentationtools.Pipe.Pipe.Pipe.close

.. automethod:: abjad.tools.documentationtools.Pipe.Pipe.Pipe.communicate

   .. note:: Inherited from `subprocess.Popen`

.. automethod:: abjad.tools.documentationtools.Pipe.Pipe.Pipe.kill

   .. note:: Inherited from `subprocess.Popen`

.. automethod:: abjad.tools.documentationtools.Pipe.Pipe.Pipe.poll

   .. note:: Inherited from `subprocess.Popen`

.. automethod:: abjad.tools.documentationtools.Pipe.Pipe.Pipe.read

.. automethod:: abjad.tools.documentationtools.Pipe.Pipe.Pipe.send_signal

   .. note:: Inherited from `subprocess.Popen`

.. automethod:: abjad.tools.documentationtools.Pipe.Pipe.Pipe.terminate

   .. note:: Inherited from `subprocess.Popen`

.. automethod:: abjad.tools.documentationtools.Pipe.Pipe.Pipe.wait

   .. note:: Inherited from `subprocess.Popen`

.. automethod:: abjad.tools.documentationtools.Pipe.Pipe.Pipe.write

.. automethod:: abjad.tools.documentationtools.Pipe.Pipe.Pipe.writeline

Special Methods
---------------

.. automethod:: abjad.tools.documentationtools.Pipe.Pipe.Pipe.__del__

   .. note:: Inherited from `subprocess.Popen`

.. automethod:: abjad.tools.documentationtools.Pipe.Pipe.Pipe.__delattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.documentationtools.Pipe.Pipe.Pipe.__eq__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.documentationtools.Pipe.Pipe.Pipe.__ge__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.documentationtools.Pipe.Pipe.Pipe.__gt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.documentationtools.Pipe.Pipe.Pipe.__hash__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.documentationtools.Pipe.Pipe.Pipe.__le__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.documentationtools.Pipe.Pipe.Pipe.__lt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.documentationtools.Pipe.Pipe.Pipe.__ne__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.documentationtools.Pipe.Pipe.Pipe.__repr__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.documentationtools.Pipe.Pipe.Pipe.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.documentationtools.Pipe.Pipe.Pipe.__str__

   .. note:: Inherited from `__builtin__.object`
